polyfemos.front.sohplot.offsets — polyfemos 0.3.29 documentation

# polyfemos.front.sohplot.offsets

Contains class `UWVOffsets`.

copyright

  2019, University of Oulu, Sodankyla Geophysical Observatory

license

  GNU Lesser General Public License v3.0 or later (https://spdx.org/licenses/LGPL-3.0-or-later.html)

Public Functions

`polyfemos.front.sohplot.offsets.` `init_definitions`()

  Updates the definition values with userdefined values from YAML files.

Classes

`UWVOffsets`() | A class for UWV to NEZ conversion